pub struct ProgramHeader {
    pub p_type: ProgType,
    pub p_offset: u64,
    pub p_vaddr: u64,
    pub p_paddr: u64,
    pub p_filesz: u64,
    pub p_memsz: u64,
    pub p_flags: ProgFlag,
    pub p_align: u64,
}
Encapsulates the contents of an ELF Program Header

The program header table is an array of program header structures describing the various segments for program execution.

Fields

p_type: ProgType

Program segment type

p_offset: u64

Offset into the ELF file where this segment begins

p_vaddr: u64

Virtual adress where this segment should be loaded

p_paddr: u64

Physical address where this segment should be loaded

p_filesz: u64

Size of this segment in the file

p_memsz: u64

Size of this segment in memory

p_flags: ProgFlag

Flags for this segment

p_align: u64

file and memory alignment

Implementations