Struct elf::segment::ProgramHeader
source · [−]pub struct ProgramHeader {
pub p_type: ProgType,
pub p_offset: u64,
pub p_vaddr: u64,
pub p_paddr: u64,
pub p_filesz: u64,
pub p_memsz: u64,
pub p_flags: ProgFlag,
pub p_align: u64,
}Expand description
Encapsulates the contents of an ELF Program Header
The program header table is an array of program header structures describing the various segments for program execution.
Fields
p_type: ProgTypeProgram segment type
p_offset: u64Offset into the ELF file where this segment begins
p_vaddr: u64Virtual adress where this segment should be loaded
p_paddr: u64Physical address where this segment should be loaded
p_filesz: u64Size of this segment in the file
p_memsz: u64Size of this segment in memory
p_flags: ProgFlagFlags for this segment
p_align: u64file and memory alignment
Implementations
sourceimpl ProgramHeader
impl ProgramHeader